# Project description
The purpose of this package is to help users analyze Binomial and Gaussian distributions.

## Introduction
To install this package, from you VM type:
```
pip install
```

## Files
Binomialdistribution.py - Binomial distribution class for calculating and visualizing a Binomial distribution.
Gaussiandistribution.py - Gaussian distribution class for calculating and visualizing a Gaussian distribution.
Generaldistribution.py - Generic distribution class for calculating and visualizing a probability distribution.